# This file is auto-generated by the Perl DateTime Suite time zone
# code generator (0.08) This code generator comes with the
# DateTime::TimeZone module distribution in the tools/ directory

#
# Generated from /tmp/KyCIpq05Oa/southamerica.  Olson data version 2017b
#
# Do not edit this file directly.
#
package DateTime::TimeZone::America::Guyana;

use strict;
use warnings;
use namespace::autoclean;

our $VERSION = '2.12';

use Class::Singleton 1.03;
use DateTime::TimeZone;
use DateTime::TimeZone::OlsonDB;

@DateTime::TimeZone::America::Guyana::ISA = ( 'Class::Singleton', 'DateTime::TimeZone' );

my $spans =
[
    [
DateTime::TimeZone::NEG_INFINITY, #    utc_start
60405105160, #      utc_end 1915-03-01 03:52:40 (Mon)
DateTime::TimeZone::NEG_INFINITY, #  local_start
60405091200, #    local_end 1915-03-01 00:00:00 (Mon)
-13960,
0,
'LMT',
    ],
    [
60405105160, #    utc_start 1915-03-01 03:52:40 (Mon)
62311693500, #      utc_end 1975-07-31 03:45:00 (Thu)
60405091660, #  local_start 1915-03-01 00:07:40 (Mon)
62311680000, #    local_end 1975-07-31 00:00:00 (Thu)
-13500,
0,
'-0345',
    ],
    [
62311693500, #    utc_start 1975-07-31 03:45:00 (Thu)
62798382000, #      utc_end 1991-01-01 03:00:00 (Tue)
62311682700, #  local_start 1975-07-31 00:45:00 (Thu)
62798371200, #    local_end 1991-01-01 00:00:00 (Tue)
-10800,
0,
'-03',
    ],
    [
62798382000, #    utc_start 1991-01-01 03:00:00 (Tue)
DateTime::TimeZone::INFINITY, #      utc_end
62798367600, #  local_start 1990-12-31 23:00:00 (Mon)
DateTime::TimeZone::INFINITY, #    local_end
-14400,
0,
'-04',
    ],
];

sub olson_version {'2017b'}

sub has_dst_changes {0}

sub _max_year {2027}

sub _new_instance {
    return shift->_init( @_, spans => $spans );
}



1;

